/***************************************************************************

    In this test, it is very important to notice how k_Crypto() and
    k_CryptoHi() return NIL, while k_Encrpyt() returns a value.

    k_Crypto() and k_CryptoHi() directly modify the variable passed
    (even if you do not pass it by reference with the "@" operator).

    k_Encrypt() does not modify the variable passed but returns a value
    that is the encrpyted value of the variable passed.

    This is an important difference.  Any call to k_Crypto() or
    k_CryptoHi() is going to CHANGE THE VARIABLE.  k_Encrypt() will
    simply return an encrpyted value.

    In the below test, watch what happens when k_Encrypt() is called.
    It returns an encrpyted value, but it is the encrpyted value of
    "x" which is itself already encrypted.


***************************************************************************/

#define SEP_LINE    repl('-',75)

FUNCTION main()

LOCAL    x := 'KIRBY L. WALLACE'
LOCAL    y := 'DATAKEY'

LOCAL    i
LOCAL    cVal
LOCAL    nStart

? k_CryptoHI(x,y)  // Higher security medium speed
? "k_CryptoHi()", x
? SEP_LINE

? k_Crypto(x,y)    // High speed low security
? "kCrypto()", x
? SEP_LINE

? k_Encrypt(x,y)   // highest level of security, but slowest.
? "k_Encrpyt()", x
? SEP_LINE

? repl(chr(210),75)

? k_CryptoHI(k_CryptoHI(x,y),y)
? "k_CryptoHi()", x
? SEP_LINE

? k_Crypto(k_Crypto(x,y),y)
? "k_Crypto()",x
? SEP_LINE

? k_Encrypt(k_Encrypt(x,y),y)
? "k_Encrypt()", x

WAIT

CLEAR SCREEN

cVal = "Long ago, in a galaxy far, far away.."

? "Now let's compare the speed of each..."

? "100,000 loops of k_Crypto()..."
nStart = seconds()
for i = 1 to 100000
    @ row(),50 say i
    k_Crypto( cVal, "ENCRYPTION KEY" )
next
?? seconds()-nStart

? "2,500 loops of k_CryptoHi()..."
nStart = seconds()
for i = 1 to 2500
    @ row(),50 say i
    k_CryptoHi( cVal, "ENCRYPTION KEY" )
next
?? seconds()-nStart


? "100 loops of k_Encrypt()..."
nStart = seconds()
for i = 1 to 100
    @ row(),50 say i
    cVal = k_Encrypt( cVal, "ENCRYPTION KEY" )
next
?? seconds()-nStart

?
? "As you can see, k_Crypto() is by far the fastest.  k_Encrypt() is"
? "by far the slowest.  The middle ground is held by k_CryptoHi()"
?
? "In terms of the most 'scrambling' done by each, k_Encrypt() probably"
? "offers the best security; k_Crypto() the least, and again k_CryptoHi()"
? "holding the middle ground with a pretty decent split between speed and"
? "security. In any case, all of them use XOR encryption and all of them"
? "offer better protection than 'positional offset' schemes or plain"
? "substitution patterns that seem to be so common in Clipper programs."
?

RETURN(NIL)

