/*****************************************************************************

    This program is used to create the Quick-Reference Guide included with
    the Klipper Library Distribution zip file.

    When run in the directory that contains all your .PRG files, this program
    will create a quick-reference entry for each source file it finds.

    The resulting text file is called QUICKREF.TXT.

    COPY MAKEQREF.EXE to the dir that contains all the Klipper Lib .PRG files
    and run it there.

    Note that the structure of the source code header files MUST be:

            FUNCTION:

            PARAMETERS:

            SHORT:

            DESCRIPTION:

            NOTE:

            EXAMPLE:


    Each of the above tokens must be on a line by itself.  That is, for
    instance, the function token cannot be:

        FUNCTION: k_FuncName()

    ...but rather must be:

        FUNCTION:

        k_FuncName()


*****************************************************************************/

#include "fileio.ch"
#include "klipper.ch"

FUNCTION main()

LOCAL    acPrgFiles := directory("*.PRG")
LOCAL    nHandle := 0
LOCAL    oHandle := fcreate("QUICKREF.TXT")
LOCAL    i := 0
LOCAL    cLine := ""

asort(acPrgFiles,,, {|x,y| x[1] < y[1]})

if oHandle > 0

    for i = 1 to len(acPrgFiles)

        nHandle = fopen(acPrgFiles[i,1])

        if nHandle > 0

            ? "Extracting Q-Reference text: ", acPrgFiles[i,1]

            // skip to the function declaration
            while substr(ltrim(k_Readline(nHandle)),1,9) != "FUNCTION:" .and. !k_FEOF(nHandle) ; end

            while !k_FEOF(nHandle)

                cLine = k_Readline(nHandle)

                if substr(ltrim(cLine),1,11) == "PARAMETERS:" .or. k_FEOF(nHandle)
                    EXIT
                endif

                if empty(cLine)
                    LOOP
                endif

                k_FWriteLine(oHandle,CRLF+cLine)

            end

            // skip to the short description
            while substr(ltrim(k_Readline(nHandle)),1,6) != "SHORT:" .and. !k_FEOF(nHandle) ; end

            while !k_FEOF(nHandle)

                cLine = k_Readline(nHandle)

                if substr(ltrim(cLine),1,12) == "DESCRIPTION:" .or. k_FEOF(nHandle)
                    EXIT
                endif

                if empty(cLine)
                    LOOP
                endif

                k_FWriteLine(oHandle,CRLF+cLine)

            end

        else
            k_Terminate("Aaaaaaaaaaaghhhhhhhhh!  Something went horribly wrong opening: "+acPrgFiles[i,1])
        endif

        k_FWriteLine(oHandle,CRLF+repl("-",80))
        fclose(nHandle)

    next

    fclose(oHandle)

else

    k_Terminate("Aaaaaaaaghhhhhh!  Something went horribly wrong with the QUICKREF.TXT file!!!")

endif

RETURN(NIL)

